/*
 * Device Driver for DataTranslation DT2801
 *
 *
 */

#ifndef _DT2801_DIO_H
#define _DT2801_DIO_H 1
#ifdef __KERNEL__

#define DT2801_DIO_NPORTS 2 
#define DT2801_DIO_PORTSIZE 8 

/* Minor device numbers */
#define DT2801_DIO0     0x30  /* port 0, 8-bit */
#define DT2801_DIO1     0x31  /* port 1, 8-bit */
#define DT2801_DIO2     0x32  /* port 0 and 1 treated as one 16-bit port */
#define DT2801_DIOX     0x3f  /* the generic dio-device */
#define DT2801_DIOL0    0x20  /* single-line device */
#define DT2801_DIOL15   0x2f  /* single-line device */

#define DT2801_DIO_P0     (0)
#define DT2801_DIO_P1     (1)
#define DT2801_DIO_P2     (2)


#define DT2801_DIO_PORTUNDEF -1
#define DT2801_DIO_PORTIN 0 
#define DT2801_DIO_PORTOUT 1 

typedef unsigned short uint16;

typedef struct {
	int usecount;
	int mode;
	int lines; /* lower 8 bits only */
} DIO_port;

typedef struct {
	int usecount;
	int nports;
        DIO_port ports[DT2801_DIO_NPORTS];
} DIO_state;

typedef struct {
        Dt2801_t* board;

	uint16 lines;
	int port;
	int mode;
	int exttrigger;
} DIOP;

extern struct file_operations dt2801_dio_fops;
extern int dt2801_dio_init(Dt2801_t*);
extern void dt2801_dio_info(Dt2801_t*);
extern int dt2801_dio_cleanup(Dt2801_t*);
extern int dt2801_dio_reset(Dt2801_t*);
extern int dt2801_dio_open(struct inode *inode, struct file *filp);

#endif /* __KERNEL__ */

#define DT2801_IOCTL_DIO_SET_LINES _IOW(DT2801_MAGIC, 0x31, uint16)

#endif /* _DT2801_DIO_H */
